## Summary

<!-- Provide a brief description of what this PR does -->

Clickup Ticket(s): Link(s) if applicable.

## Type of Change

- [ ] 🐛 Bug fix (non-breaking change that fixes an issue)
- [ ] ✨ New feature (non-breaking change that adds functionality)
- [ ] 💥 Breaking change (fix or feature that would cause existing functionality to not work as expected)
- [ ] 📝 Documentation update
- [ ] 🔧 Refactoring (no functional changes)
- [ ] ⚡ Performance improvement
- [ ] 🧪 Test improvements
- [ ] 🔒 Security fix

## Changes Made

<!-- List the main changes made in this PR -->
-
-
-

## Testing

<!-- Describe how you tested these changes -->
- [ ] Tests pass locally (`uv run pytest tests/`)
- [ ] Type checking passes (`uv run mypy <src_dir>`)
- [ ] Linting passes (`uv run ruff check src_dir/`)
- [ ] Manual testing performed (describe below)

**Manual testing details:**
<!-- Describe any manual testing performed -->

## Screenshots/Recordings

<!-- If applicable, add screenshots or recordings to demonstrate the changes -->

## Related Issues

<!-- Link any related issues using "Closes #123" or "Relates to #123" -->

## Deployment Notes

<!-- Any special deployment considerations or migration steps -->

## Checklist

- [ ] Code follows the project's style guidelines
- [ ] Self-review of code completed
- [ ] Documentation updated (if applicable)
- [ ] No sensitive information (API keys, credentials) exposed
